@@ -32,6 +32,9 @@ class UpdaterQQ(QThread):
         self.callback=callback
         self.logger.debug("UpdaterQQ:__init__")
         self.accountId=accountId
+        self.userid = 0
+        self.users = []
+        self.update_user_follower_pending = False
 
     def basicAuth(self, source, username, password):
         self.auth = BasicAuthHandler(username, password)
@@ -47,9 +50,9 @@ class UpdaterQQ(QThread):
         
         self.auth = OAuthHandler(APP_KEY,APP_SECRET)
         self.auth.setToken(username, password)
-        self.api = API(self.auth, parser=JSONParser())
+        self.api = API(self.auth, parser=JSONParser(), log = self.logger)
 
-    def initialize(self, accountId,timelineType,pageflat = 0,pagetime = 0,countnum=0,downpic="True", rootid=None, optype = None):
+    def initialize(self, accountId,timelineType,pageflat = 0,pagetime = 0,countnum=0,downpic="True", rootid=None, optype = None, uid=None, screen_name=None):
         self.logger.debug("UpdaterQQ:initialize")
         self.stopped = False
         self.accountId=accountId
@@ -62,7 +65,10 @@ class UpdaterQQ(QThread):
         self.timeline = []
         self.rootid = rootid
         self.unread_counts = {}
-        self.optype = optype
+        self.optype = optype # for clear unread counts
+        self.uid = uid # for getting user detail info.
+        self.screen_name = screen_name # for getting user detail info.
+        self.update_user_follower_pending = False
 
 
     def stop(self):
@@ -83,13 +89,99 @@ class UpdaterQQ(QThread):
     def run(self):
         self.logger.debug("run")
         try:
-            self.update_timeline(self.pageflat,self.pagetime,self.countnum,self.rootid)
+            if self.update_user_follower_pending != False:
+                self.update_user_follower_pending = False
+                self.update_user_follower_process()
+            else:
+                self.update_timeline(self.pageflat,self.pagetime,self.countnum,self.rootid)           
+
         except WeibopError,we:
             self.completed=False
             self.emit(SIGNAL("finished(bool)"),self.completed)
             self.emit(SIGNAL("show_notice(QString,int)"),we.reason,0)
         self.stop()
+        
+    def get_userid(self):
+        ''' get current account userid'''
+        
+        if self.userid == 0:
+            user = self.api.user.info()
+            
+            if user:
+                self.userid = user['data']['name']
+            else:
+                print "get_userid failed"
+        return self.userid
 
+        
+    def get_friendship(self, user):
+        #print "get_friendship2me"
+        friendship = {}
+        
+        if user['id'] == self.get_userid():
+            friendship["self"] = True
+        else:
+            friendship["self"] = False
+            
+        friendship["following"] = user['ismyfans']
+        friendship["followed_by"] = user['ismyidol']
+            
+        return friendship
+
+    def update_user_follower(self, uid, accountid, downpic, cursor = 0, getFans = False, count = 20):
+        #print "update_user_follower"
+        self.users = []
+        self.uid = uid
+        self.accountId = accountid
+        self.downpic=downpic
+        
+        self.param={}
+        self.param["name"]=uid
+        self.param["startindex"]=cursor
+        self.param["reqnum"]=count
+        self.update_user_follower_pending = True
+        self.getFans = getFans
+        
+    def update_user_follower_process(self):
+        #print "update_user_follower_process"
+        users = None
+        if self.getFans:        
+            #print "update_user_follower_process: fans"
+            users = self.api.friends.userfanslist(**self.param)
+        else:
+            #print "update_user_follower_process: friends"
+            users = self.api.friends.useridollist(**self.param)
+        #print target.screen_name, target.following, target.followed_by
+
+        if users != None:
+            for obj in users['data']['info']:
+                user = Utils.build_a_user_from_obj_qq(obj, self.accountId)
+                self.users.append(user)
+                
+                status = None
+                
+                # download images.
+                #print str(time.time()) + ": " + "Begin downloading images"
+                if self.downpic=="True":
+                    avatar=user["profile_image_url"]
+                    if avatar!=None:
+                        picFilename=Utils.AVATAR_DIR+str(self.accountId)+"_"+str(user["id"])
+                        if os.access(picFilename, os.W_OK) == 0:
+                            picSource=self.downloader.download(avatar)
+                            self.writer.write_to(picFilename, picSource)
+        else:
+            self.users = {}
+            self.emit(SIGNAL("userlist_finished(bool)"), True)
+            return
+
+        self.next_cursor = self.param["startindex"]+self.param["reqnum"]
+        
+        if users['data']['hasnext'] == 0:
+            hasnext = True
+        else:
+            hasnext = False           
+
+        self.emit(SIGNAL("userlist_finished(bool)"), hasnext)
 
     def update_timeline(self,pageFlag=0,pagetime=0,countNum=10, rootid=None):
         self.logger.debug("update_timeline")
@@ -101,49 +193,79 @@ class UpdaterQQ(QThread):
         param["pageflag"]=pageFlag
         param["pagetime"]=pagetime
         timeline=None
-        
-        if self.timelineType==Utils.TIMELINE_TYPE_FRIENDS:
-            timeline = self.api.timeline.home(**param)
-        elif self.timelineType==Utils.TIMELINE_TYPE_DM:
-            timeline = self.api.timeline.broadcast(**param)
-        elif self.timelineType==Utils.TIMELINE_TYPE_MENTIONS:
-            timeline = self.api.timeline.mentions(**param)
-        elif self.timelineType==Utils.TIMELINE_TYPE_COMMENTS:
-            param["type"]=80
-            timeline = self.api.timeline.broadcast(**param)
-        elif self.timelineType==Utils.TIMELINE_TYPE_ST_COMMENTS:
-            param1["twitterid"]=0
-            param1["reqnum"]=countNum
-            param1["pageflag"]=pageFlag
-            param1["pagetime"]=pagetime            
-            param1["rootid"]= rootid           
-            param1["flag"]=1
-            timeline = self.api.tweet.retweetlist(**param1)
-        elif self.timelineType==Utils.TIMELINE_TYPE_FAVOUR:
-            param={}
-            param["source"]=APP_KEY
-            param["id"]=1863105202
-            timeline = self.api.favorites(**param)
-        elif self.timelineType==Utils.TIMELINE_TYPE_UNREAD:
-            param={}
-            param["op"]=0
-            timeline = self.api.info.update(**param)
-        elif self.timelineType==Utils.TIMELINE_TYPE_DEUNREAD:
-            param={}
-            param["op"]=1
-            if self.optype == Utils.TIMELINE_TYPE_MENTIONS:
-                param["type"]=6
-            elif self.optype == Utils.TIMELINE_TYPE_COMMENTS:    
-                param["type"]=5 # not support get unread comment counts
-            timeline = self.api.info.update(**param)
+
+        try:
+            if self.timelineType==Utils.TIMELINE_TYPE_FRIENDS:
+                timeline = self.api.timeline.home(**param)
+            elif self.timelineType==Utils.TIMELINE_TYPE_DM:
+                timeline = self.api.timeline.broadcast(**param)
+            elif self.timelineType==Utils.TIMELINE_TYPE_MENTIONS:
+                timeline = self.api.timeline.mentions(**param)
+            elif self.timelineType==Utils.TIMELINE_TYPE_COMMENTS:
+                param["type"]=80
+                timeline = self.api.timeline.broadcast(**param)
+            elif self.timelineType==Utils.TIMELINE_TYPE_ST_COMMENTS:
+                param1["twitterid"]=0
+                param1["reqnum"]=countNum
+                param1["pageflag"]=pageFlag
+                param1["pagetime"]=pagetime            
+                param1["rootid"]= rootid           
+                param1["flag"]=1
+                timeline = self.api.tweet.retweetlist(**param1)
+            elif self.timelineType==Utils.TIMELINE_TYPE_FAVOUR:
+                param={}
+                param["source"]=APP_KEY
+                param["id"]=1863105202
+                timeline = self.api.favorites(**param)
+            elif self.timelineType==Utils.TIMELINE_TYPE_UNREAD:
+                param={}
+                param["op"]=0
+                timeline = self.api.info.update(**param)
+            elif self.timelineType==Utils.TIMELINE_TYPE_DEUNREAD:
+                param={}
+                param["op"]=1
+                if self.optype == Utils.TIMELINE_TYPE_MENTIONS:
+                    param["type"]=6
+                elif self.optype == Utils.TIMELINE_TYPE_COMMENTS:    
+                    param["type"]=5 # not support get unread comment counts
+                elif self.optype == Utils.TIMELINE_TYPE_FAVOUR:    
+                    param["type"]=8 # not support get unread comment counts
+                timeline = self.api.info.update(**param)
+            elif self.timelineType==Utils.TIMELINE_TYPE_USER_SHOW:
+                param={}
+                #print "update_timeline, optype", self.optype
+                if self.screen_name == None:
+                    param["name"]=self.uid
+                else:
+                    param["name"]=self.screen_name
+                timeline = self.api.user.userinfo(**param)
+            elif self.timelineType==Utils.TIMELINE_TYPE_USER_TIMELINE:
+                #print "update_timeline, uid", self.screen_name
+                param["name"]=self.screen_name
+                timeline = self.api.timeline.user(**param)
+        except UnicodeDecodeError, e:
+            print e
+            param["pageflag"]=1
+            param["pagetime"]=time.time()
+
+            
+            if self.timelineType==Utils.TIMELINE_TYPE_FRIENDS:
+                timeline = self.api.timeline.home(**param)
+            elif self.timelineType==Utils.TIMELINE_TYPE_DM:
+                timeline = self.api.timeline.broadcast(**param)
+            elif self.timelineType==Utils.TIMELINE_TYPE_MENTIONS:
+                timeline = self.api.timeline.mentions(**param)
+            elif self.timelineType==Utils.TIMELINE_TYPE_COMMENTS:
+                param["type"]=80
+                timeline = self.api.timeline.broadcast(**param)
 	
-        if timeline['data']!=None and self.timelineType != Utils.TIMELINE_TYPE_UNREAD and self.timelineType != Utils.TIMELINE_TYPE_DEUNREAD: 
+        if self.timelineType == Utils.TIMELINE_TYPE_USER_SHOW and timeline!=None:
+            self.user = Utils.build_a_user_from_obj_qq(timeline['data'], self.accountId)
+            self.user["profile_image_url"]
+            self.user["avatar_large"] = timeline['data']["head"]+ "/180"
+            #print self.user["avatar_large"],  self.user["profile_image_url"]
+        elif timeline['data']!=None and self.timelineType != Utils.TIMELINE_TYPE_UNREAD and self.timelineType != Utils.TIMELINE_TYPE_DEUNREAD: 
             for line in timeline['data']['info']:
-                
-                #print line["id"]
-                #print line["text"]
-                #print line["origtext"]
-                #print "------------------"
                 status=Utils.build_a_status_from_obj_qq(line,self.accountId)
                 
                 self.timeline.append(status)
@@ -186,12 +308,13 @@ class UpdaterQQ(QThread):
                                 picSource=self.downloader.download(rtThumbnail)
                                 self.writer.write_to(picFilename, picSource)
         elif timeline['data']!=None and self.timelineType == Utils.TIMELINE_TYPE_UNREAD:
-            #print "Utils.TIMELINE_TYPE_UNREAD"
             self.unread_counts = Utils.build_a_unread_count_from_obj_qq(timeline["data"])
             
         self.completed = True
         if self.timelineType==Utils.TIMELINE_TYPE_UNREAD:
             self.emit(SIGNAL("unread_finished(int)"),self.accountId)
+        elif self.timelineType==Utils.TIMELINE_TYPE_USER_SHOW:
+            self.emit(SIGNAL("user_finished(QString, QString)"), str(self.uid), str(self.screen_name))
         elif self.timelineType!=Utils.TIMELINE_TYPE_ST_COMMENTS and self.timelineType!=Utils.TIMELINE_TYPE_DEUNREAD: 
             self.emit(SIGNAL("finished(bool)"),self.completed)
         else:
@@ -298,6 +421,7 @@ class SenderQQ(QThread):
                     status=self.api.tweet.retweet(**param)
                 #print "and comment it"   
                 time.sleep(5)
+                print param
                 status=self.api.tweet.comment(**param)
             except KeyError,ae:
                 pass
@@ -317,4 +441,15 @@ class SenderQQ(QThread):
         self.completed = True
         self.emit(SIGNAL("finished(bool)"),self.completed)
         self.logger.info("sending completed!")
-
+        
+    def add_follower(self, screen_name):
+        #print "add_follower"
+        param={}
+        param["name"]=screen_name
+        self.api.friends.add(**param)   
+        
+    def delete_follower(self, screen_name):
+        #print "delete_follower"
+        param={}
+        param["name"]=screen_name
+        self.api.friends.delete(**param)
\ No newline at end of file
