@@ -89,15 +89,16 @@ class MaoboApp(QApplication):
     # Connect the "handler" to the orientation changed signal of mce
         sysbus.add_signal_receiver(self.OrientationHandler, signal_name=MCE_SIGNAL_NAME, dbus_interface=MCE_SIGNAL_IFACE, path=MCE_SIGNAL_PATH)
 
-        self.osso_c = osso.Context(SH_DBUS_NAME,"0.0.1",False)
-        self.osso_rpc = osso.Rpc(self.osso_c)
-        self.osso_rpc.set_rpc_callback(SH_DBUS_NAME, SH_DBUS_PATH, SH_DBUS_IFACE, self.send_via_service, self.osso_c)
+        Utils.init_osso_context(SH_DBUS_NAME)
+        
+        Utils.osso_rpc.set_rpc_callback(SH_DBUS_NAME, SH_DBUS_PATH, SH_DBUS_IFACE, self.send_via_service, Utils.osso_c)
 
         print str(time.time()) + ": " + "MaoboApp __init__ a" 
         self.charm = FlickCharm()
 
         #print str(time.time()) + ": " + "MaoboApp __init__ b"   
         self.controller=Controller()
+        Utils.init_controller()
 
         print str(time.time()) + ": " + "MaoboApp __init__ c"   
         
@@ -111,25 +112,27 @@ class MaoboApp(QApplication):
         self.connect(self.updatersina, SIGNAL("show_notice(QString,int)"), self.show_notice)
         self.connect(self.sendersina, SIGNAL("show_notice(QString,int)"), self.show_notice)
         self.connect(self.updatersina, SIGNAL("cm_finished(bool)"), self.update_comments_finished)
+        self.connect(self.updatersina, SIGNAL("user_finished(QString, QString)"), self.update_user_finished)
 
         self.connect(self.updaterqq, SIGNAL("finished(bool)"), self.update_finished)
         self.connect(self.senderqq, SIGNAL("finished(bool)"), self.send_finished)
         self.connect(self.updaterqq, SIGNAL("show_notice(QString,int)"), self.show_notice)
         self.connect(self.senderqq, SIGNAL("show_notice(QString,int)"), self.show_notice)
         self.connect(self.updaterqq, SIGNAL("cm_finished(bool)"), self.update_comments_finished)
+        self.connect(self.updaterqq, SIGNAL("user_finished(QString, QString)"), self.update_user_finished)
 
         self.currentStatus=None
         self.timelineType=None
         self.accounts=self.controller.get_all_accounts()
         self.websites=self.controller.get_all_websites()
-        self.settings=self.controller.get_settings()
+        Utils.settings=self.controller.get_settings()
         
         self.currentAccount=None
 
         self.commentid_seed = 0
-        self.create_default_window()
         self.create_accounts_window()
         if len(self.accounts)==0:
+            self.create_default_window()
             self.defaultWin.show()
         else:
             self.accountsWin.show()
@@ -144,13 +147,14 @@ class MaoboApp(QApplication):
 
         print str(time.time()) + ": " + "MaoboApp __init__ 2"
                  
-        Utils.g_orietation=self.get_current_orientation()
-        print Utils.g_orietation
+        Utils.g_orientation=self.get_current_orientation()
+        #print Utils.g_orietation
         self.create_timeline_window()
         self.create_status_window()
         self.newStatusWin=None
         self.accountsManaForm=None
         self.newAccountForm=None
+        self.userWin = None
 
         self.init_unread_updaters()
         
@@ -230,16 +234,16 @@ class MaoboApp(QApplication):
     def cb_update_unread_counts(self):
         #print "cb_update_unread_counts"
         
-        conn_status = self.osso_rpc.rpc_run("com.nokia.icd", "/com/nokia/icd", "com.nokia.icd", "get_state", wait_reply=True, use_system_bus=True)
+        conn_status = Utils.osso_rpc.rpc_run("com.nokia.icd", "/com/nokia/icd", "com.nokia.icd", "get_state", wait_reply=True, use_system_bus=True)
         #print "conn_status",conn_status
 
-        if conn_status == 0 and self.settings["auto_conn"] != "---None---":
+        if conn_status == 0 and Utils.settings["auto_conn"] != "---None---":
             #print "try to auto-connect internet - status: %s" % (self.sm_auto_update_unread)
             self.sm_auto_update_unread = _SM_AUTO_CONNECTING
 
             #dbus-send --type=method_call --system --dest=com.nokia.icd /com/nokia/icd com.nokia.icd.connect string:"d8a643a0-a0a6-4db2-9b87-759e6fd0f969" uint32:0
-            ret=self.osso_rpc.rpc_run("com.nokia.icd", "/com/nokia/icd", "com.nokia.icd", "connect", \
-                rpc_args=(self.settings["auto_conn"], 0), wait_reply=True, use_system_bus=True)
+            ret=Utils.osso_rpc.rpc_run("com.nokia.icd", "/com/nokia/icd", "com.nokia.icd", "connect", \
+                rpc_args=(Utils.settings["auto_conn"], 0), wait_reply=True, use_system_bus=True)
 
             self.t = threading.Timer(15, self.cb_update_unread_counts)
             self.t.start()
@@ -256,9 +260,9 @@ class MaoboApp(QApplication):
                 self.unread_updaters[acc].start()
 
         if self.is_app_background_mode(): 
-            self.t = threading.Timer(60*float(self.settings["updateinterval2"]), self.cb_update_unread_counts)
+            self.t = threading.Timer(60*float(Utils.settings["updateinterval2"]), self.cb_update_unread_counts)
         else:
-            self.t = threading.Timer(60*float(self.settings["updateinterval"]), self.cb_update_unread_counts)
+            self.t = threading.Timer(60*float(Utils.settings["updateinterval"]), self.cb_update_unread_counts)
             
         self.t.start()
             
@@ -267,8 +271,8 @@ class MaoboApp(QApplication):
 
         #print self.accountsWin.isVisible()
 
-        #diplay_status =self.osso_rpc.rpc_run(MCE_SERVICE, MCE_REQUEST_PATH, MCE_REQUEST_IF, MCE_DEVICE_DISPSTATUS_GET, wait_reply=True, use_system_bus=True)  
-        #scr_lock_status =self.osso_rpc.rpc_run(MCE_SERVICE, MCE_REQUEST_PATH, MCE_REQUEST_IF, MCE_DEVICE_SCRLOCK_GET, wait_reply=True, use_system_bus=True)  
+        #diplay_status =Utils.osso_rpc.rpc_run(MCE_SERVICE, MCE_REQUEST_PATH, MCE_REQUEST_IF, MCE_DEVICE_DISPSTATUS_GET, wait_reply=True, use_system_bus=True)  
+        #scr_lock_status =Utils.osso_rpc.rpc_run(MCE_SERVICE, MCE_REQUEST_PATH, MCE_REQUEST_IF, MCE_DEVICE_SCRLOCK_GET, wait_reply=True, use_system_bus=True)  
 
         if optype == Utils.TIMELINE_TYPE_MENTIONS:
             keystr = "条@我的新消息"
@@ -286,16 +290,16 @@ class MaoboApp(QApplication):
 
         print "notify [" +str(account_idx)+":t"+str(optype)+"], msgs", msgs   
         self.unread_notifiers[str(account_idx)+":t"+str(optype)] = msgs      
-        self.osso_rpc.rpc_run(NOTIFY_DBUS_NAME, NOTIFY_DBUS_PATH, \
+        Utils.osso_rpc.rpc_run(NOTIFY_DBUS_NAME, NOTIFY_DBUS_PATH, \
             NOTIFY_DBUS_IFACE, NOTIFY_SHARE_SIG_SHOW, 
             rpc_args=(str(account_idx), str(optype), str(nickname), \
             nickname+"﻿收到"+str(msgs)+keystr, iconstr), wait_reply=False, use_system_bus=False)
             
-        if self.settings["notify_led"] == "True":
-            self.osso_rpc.rpc_run(MCE_SERVICE, MCE_REQUEST_PATH, MCE_REQUEST_IF, ENABLE_LED, rpc_args=(LED_PATTERN,"",""),use_system_bus=True)            
-        if self.settings["notify_vibra"] == "True":
-            self.osso_rpc.rpc_run(MCE_SERVICE, MCE_REQUEST_PATH, MCE_REQUEST_IF, VIBRATE, rpc_args=(VIBRATE_PATTERN,"",""),use_system_bus=True)            
-        if self.settings["notify_sound"] == "True":
+        if Utils.settings["notify_led"] == "True":
+            Utils.osso_rpc.rpc_run(MCE_SERVICE, MCE_REQUEST_PATH, MCE_REQUEST_IF, ENABLE_LED, rpc_args=(LED_PATTERN,"",""),use_system_bus=True)            
+        if Utils.settings["notify_vibra"] == "True":
+            Utils.osso_rpc.rpc_run(MCE_SERVICE, MCE_REQUEST_PATH, MCE_REQUEST_IF, VIBRATE, rpc_args=(VIBRATE_PATTERN,"",""),use_system_bus=True)            
+        if Utils.settings["notify_sound"] == "True":
             bus = dbus.SessionBus()            
             proxy = bus.get_object('com.nokia.HildonSVNotificationDaemon', '/com/nokia/HildonSVNotificationDaemon')            
             interface = dbus.Interface(proxy,dbus_interface='com.nokia.HildonSVNotificationDaemon')            
@@ -391,6 +395,7 @@ class MaoboApp(QApplication):
                 self.defaultWin.activateWindow()
                 self.defaultWin.show()
             else:
+                print "self.accountsWin.show"
                 self.accountsWin.activateWindow()
                 self.accountsWin.show()
         elif method == "open_mentions":
@@ -400,16 +405,16 @@ class MaoboApp(QApplication):
             self.accountsWin.activateWindow()
             self.accountsWin.show()
             
-            conn_status = self.osso_rpc.rpc_run("com.nokia.icd", "/com/nokia/icd", \
+            conn_status = Utils.osso_rpc.rpc_run("com.nokia.icd", "/com/nokia/icd", \
                 "com.nokia.icd", "get_state", wait_reply=True, use_system_bus=True)
             print "conn_status",conn_status
 
-            if conn_status == 0 and self.settings["auto_conn"] != "---None---":
+            if conn_status == 0 and Utils.settings["auto_conn"] != "---None---":
                 print "try to auto-connect internet - status: %s" % (self.sm_auto_update_unread)
 
                 #dbus-send --type=method_call --system --dest=com.nokia.icd /com/nokia/icd com.nokia.icd.connect string:"d8a643a0-a0a6-4db2-9b87-759e6fd0f969" uint32:0
-                ret=self.osso_rpc.rpc_run("com.nokia.icd", "/com/nokia/icd", "com.nokia.icd", "connect", \
-                    rpc_args=(self.settings["auto_conn"], 0), wait_reply=True, use_system_bus=True)
+                ret=Utils.osso_rpc.rpc_run("com.nokia.icd", "/com/nokia/icd", "com.nokia.icd", "connect", \
+                    rpc_args=(Utils.settings["auto_conn"], 0), wait_reply=True, use_system_bus=True)
             
 
             #print self.unread_notifiers[args[0]+":t"+args[1]].isVisible()
@@ -429,7 +434,7 @@ class MaoboApp(QApplication):
         else:    
             print "Not support method: " + method
             return
-            
+    '''        
     def clean_temp_images(self, outbox_path):
         if os.path.isdir(outbox_path):
             paths = os.listdir(outbox_path)
@@ -442,7 +447,7 @@ class MaoboApp(QApplication):
                             os.remove(filePath)
                     except os.error:
                         continue
- 
+    '''
     def get_current_orientation(self):
         '''
         f = open("/sys/class/i2c-adapter/i2c-3/3-001d/coord", 'r' )
@@ -460,7 +465,7 @@ class MaoboApp(QApplication):
         orientation=None
 
         #rpc = osso.Rpc(osso_c)
-        orientation =self.osso_rpc.rpc_run(MCE_SERVICE, MCE_REQUEST_PATH, MCE_REQUEST_IF, MCE_DEVICE_ORIENTATION_GET, wait_reply=True, use_system_bus=True)       
+        orientation =Utils.osso_rpc.rpc_run(MCE_SERVICE, MCE_REQUEST_PATH, MCE_REQUEST_IF, MCE_DEVICE_ORIENTATION_GET, wait_reply=True, use_system_bus=True)       
         print orientation
         
         if orientation == 'landscape': 
@@ -478,26 +483,35 @@ class MaoboApp(QApplication):
     def OrientationHandler(self, orientation, stand, face, x, y, z):   
         #print "OrientationHandler"
         #print orientation
-        if orientation == 'landscape': 
-            Utils.g_orietation = 0
-            self.timelineWin.switch(0)
-            self.newStatusWin.switch(0)
-            #print "landscape"
-        elif orientation == "landscape (inverted)": 
-            Utils.g_orietation = 2
-            self.timelineWin.switch(2)
-            self.newStatusWin.switch(2)
-        elif orientation == 'portrait':
-            Utils.g_orietation = 1
-            self.timelineWin.switch(1)
-            self.newStatusWin.switch(1)
-            #print "portrait"
-        elif orientation ==  "portrait (inverted)":
-            Utils.g_orietation = 3
-            self.timelineWin.switch(3)
-            self.newStatusWin.switch(3)
-        else:
-            print "other orietation"
+        #orientation = 'portrait'
+        try:
+            if orientation == 'landscape': 
+                Utils.g_orientation = 0
+                self.timelineWin.switch(0)
+                #self.newStatusWin.switch(0)
+                #self.userWin.switch(0)
+                self.activeWindow().switch(Utils.g_orientation)
+                print "landscape"
+            elif orientation == "landscape (inverted)": 
+                Utils.g_orientation = 2
+                self.timelineWin.switch(2)
+                #self.newStatusWin.switch(2)
+                self.activeWindow().switch(Utils.g_orientation)
+            elif orientation == 'portrait':
+                Utils.g_orientation = 1
+                self.timelineWin.switch(1)
+                #self.newStatusWin.switch(1)
+                self.activeWindow().switch(Utils.g_orientation)
+                print "portrait"
+            elif orientation ==  "portrait (inverted)":
+                Utils.g_orientation = 3
+                self.timelineWin.switch(3)
+                self.activeWindow().switch(Utils.g_orientation)
+            else:
+                print "other orietation"
+        except:
+            print "active window does not support roatation"
+            pass
             
     def create_default_window(self):
         self.defaultWin=DefaultWindow(None)
@@ -510,7 +524,7 @@ class MaoboApp(QApplication):
         self.defaultWin.setMenuBar(self.menuBar)
 
     def create_accounts_window(self):
-        self.accountsWin=AccountsWindow(None,self.accounts,self.websites, mode=self.settings["background"])
+        self.accountsWin=AccountsWindow(None,self.accounts,self.websites, mode=Utils.settings["background"])
         self.connect(self.accountsWin.accountsListView,
                      SIGNAL("clicked(const QModelIndex&)"),
                      self.account_clicked)
@@ -539,7 +553,7 @@ class MaoboApp(QApplication):
         row=index.row()
         self.currentAccount=self.accounts[row]
         #print self.currentAccount
-        
+
         if self.currentAccount["website"]==1:
             self.updater=self.updatersina
             self.sender=self.sendersina
@@ -564,10 +578,13 @@ class MaoboApp(QApplication):
         self.unread_updaters[str(self.currentAccount["id"])].start()
 
         self.show_timeline_window()
+        self.updater.userid = 0
 
-    def create_menus_window(self):
-        self.menus=Utils.build_menus()
-        self.menusWin=MenusWindow(self.accountsWin,self.menus) #, self.currentAccount["nickname"])
+        #self.updater.get_friendship(self.updater.get_userid())#1626998064)
+
+#    def create_menus_window(self):
+#        self.menus=Utils.build_menus()
+#        self.menusWin=MenusWindow(self.accountsWin,self.menus) #, self.currentAccount["nickname"])
 
         #self.connect(self.menusWin.menuListView,SIGNAL("clicked(const QModelIndex&)"),self.menu_clicked)
 
@@ -584,6 +601,17 @@ class MaoboApp(QApplication):
             model = self.timelineWin.menuListView.model()
             self.timelineWin.menuListView.setCurrentIndex(model.index(self.timelineWin.currentMenuIdx, 0))
             self.show_new_status_window()
+        elif  value==Utils.TIMELINE_TYPE_FAVOUR:
+
+            self.show_user_window()
+            
+            # clean unread counts
+            if self.timelineWin.menuModel.need_clear_unread_count(value):
+                self.unread_updaters[str(self.currentAccount["id"])].initialize(self.currentAccount["id"], Utils.TIMELINE_TYPE_DEUNREAD, optype=value) 
+                self.unread_updaters[str(self.currentAccount["id"])].start()
+            self.timelineWin.menuModel.clear_unread_count(value) 
+            self.timelineWin.menuListView.hide()
+            self.timelineWin.menuListView.show()
         else:
             self.timelineWin.currentMenuIdx = index.row()
             self.timelineType=value      
@@ -593,7 +621,7 @@ class MaoboApp(QApplication):
         self.currentAccount = None
 
     def create_timeline_window(self):
-        self.timelineWin=TimelineWindow(self.accountsWin, orientation=Utils.g_orietation)
+        self.timelineWin=TimelineWindow(self.accountsWin, orientation=Utils.g_orientation)
         self.connect(self.timelineWin.statusesListView,SIGNAL("clicked(const QModelIndex&)"),self.status_clicked)
         self.connect(self.timelineWin.menuListView,SIGNAL("clicked(const QModelIndex&)"),self.menu_clicked)
         self.connect(self.timelineWin,SIGNAL("timelinwin_close()"),self.on_timeline_window_closed)
@@ -608,15 +636,16 @@ class MaoboApp(QApplication):
         self.currentOpe=None
 
     def create_status_window(self):
-        self.statusWin=StatusWindow(self.timelineWin)        
+        self.statusWin=StatusWindow(self.timelineWin)    
         self.connect(self.statusWin.statusesListView, SIGNAL("clicked(const QModelIndex&)"), self.cm_List_clicked)
         self.connect(self.statusWin.cmBtn, SIGNAL("clicked()"), self.cm_status_clicked)            
 
         self.connect(self.statusWin.rtBtn, SIGNAL("clicked()"), self.rt_a_status)
         self.connect(self.statusWin.cmtBtn, SIGNAL("clicked()"), self.comment_a_status)
-        self.connect(self.statusWin.dmBtn, SIGNAL("clicked()"), self.dm_a_status)
-        self.connect(self.statusWin.favBtn, SIGNAL("clicked()"), self.fav_a_status)
+        #self.connect(self.statusWin.dmBtn, SIGNAL("clicked()"), self.dm_a_status)
+        #self.connect(self.statusWin.favBtn, SIGNAL("clicked()"), self.fav_a_status)
         self.connect(self.statusWin.ReplyBtn, SIGNAL("clicked()"), self.Reply_a_status)
+        self.connect(self.statusWin.userBtn, SIGNAL("clicked()"), self.show_user)
         self.charm.activateOn(self.statusWin.statusContentView)
 
     def show_timeline_window(self):
@@ -645,13 +674,13 @@ class MaoboApp(QApplication):
         self.timelineWin.statusesListView.scrollToTop()        
         self.timelineWin.setWindowTitle(self.currentAccount["nickname"])
         self.timelineWin.show()
-        self.timelineWin.switch(Utils.g_orietation)
+        self.timelineWin.switch(Utils.g_orientation)
 
     def status_clicked(self,index):
         self.logger.debug("status_clicked")
         row=index.row()
         status=self.statuses[row]
-
+        #print QCursor.pos()
         try:
             type=status["type"]
             self.logger.debug("type:"+str(type))
@@ -685,13 +714,13 @@ class MaoboApp(QApplication):
                     sinceId=sinceStatus["id"]
                     self.currentOpe=self.gapOpe
                     self.gapRow=row
-                    self.updater.initialize(self.currentAccount["id"],self.timelineType,sinceId,maxId,self.settings["updatenum"],self.settings["downpic"])
+                    self.updater.initialize(self.currentAccount["id"],self.timelineType,sinceId,maxId,Utils.settings["updatenum"],Utils.settings["downpic"])
                 else:
                     tmpStatus=self.statuses[row-1]
                     pagetime=tmpStatus["bmiddle_pic"]
                     self.currentOpe=self.gapOpe
                     self.gapRow=row
-                    self.updater.initialize(self.currentAccount["id"],self.timelineType,1,pagetime,self.settings["updatenum"],self.settings["downpic"])
+                    self.updater.initialize(self.currentAccount["id"],self.timelineType,1,pagetime,Utils.settings["updatenum"],Utils.settings["downpic"])
                 
 #                try:
 #                    self.updater.basicAuth(Utils.APP_KEY,self.currentAccount["username"],self.currentAccount["password"])
@@ -758,7 +787,7 @@ class MaoboApp(QApplication):
             return
         self.statusWin.commentsOpe["name"]="updating, please wait"
         self.statusWin.commentsOpe["lastUpdated"]=None
-        self.statusWin.load_status(self.settings["down_orgpic"])
+        self.statusWin.load_status(Utils.settings["down_orgpic"], self.currentAccount)
         self.statusWin.setWindowTitle(self.currentAccount["nickname"])
         self.statusWin.currentOpe=self.statusWin.commentsOpe
         
@@ -769,7 +798,7 @@ class MaoboApp(QApplication):
                 sinceId=latestStatus["id"]
                 self.logger.debug("sinceId:"+str(sinceId))
             
-            self.updater.initialize(self.currentAccount["id"],Utils.TIMELINE_TYPE_ST_COMMENTS,self.statusWin.status["id"],None,self.settings["updatenum"],self.settings["downpic"])
+            self.updater.initialize(self.currentAccount["id"],Utils.TIMELINE_TYPE_ST_COMMENTS,self.statusWin.status["id"],None,Utils.settings["updatenum"],Utils.settings["downpic"])
         else:
             pageflag=0
             pagetime=0
@@ -787,7 +816,7 @@ class MaoboApp(QApplication):
                     #    pagetime=lasetime
             print self.statusWin.status["id"]
             print self.statusWin.status["user"]["name"]
-            self.updater.initialize(self.currentAccount["id"],Utils.TIMELINE_TYPE_ST_COMMENTS,pageflag,pagetime,self.settings["updatenum"],self.settings["downpic"],self.statusWin.status["id"])
+            self.updater.initialize(self.currentAccount["id"],Utils.TIMELINE_TYPE_ST_COMMENTS,pageflag,pagetime,Utils.settings["updatenum"],Utils.settings["downpic"],self.statusWin.status["id"])
         
         self.show_notice("更新中...")
         self.set_windows_status(1)
@@ -812,7 +841,7 @@ class MaoboApp(QApplication):
                 sinceId=latestStatus["id"]
                 self.logger.debug("sinceId:"+str(sinceId))
             
-            self.updater.initialize(self.currentAccount["id"],self.timelineType,sinceId,None,self.settings["updatenum"],self.settings["downpic"])
+            self.updater.initialize(self.currentAccount["id"],self.timelineType,sinceId,None,Utils.settings["updatenum"],Utils.settings["downpic"])
         else:
             pageflag=0
             pagetime=0
@@ -829,7 +858,7 @@ class MaoboApp(QApplication):
     	        #    pageflag=2
     	        #    pagetime=lasetime
     	            
-            self.updater.initialize(self.currentAccount["id"],self.timelineType,pageflag,pagetime,self.settings["updatenum"],self.settings["downpic"])
+            self.updater.initialize(self.currentAccount["id"],self.timelineType,pageflag,pagetime,Utils.settings["updatenum"],Utils.settings["downpic"])
         
         self.show_notice("更新中...")
         self.set_windows_status(1)
@@ -852,7 +881,7 @@ class MaoboApp(QApplication):
         if self.activeWindow() == None:
             return True
             
-        diplay_status =self.osso_rpc.rpc_run(MCE_SERVICE, MCE_REQUEST_PATH, MCE_REQUEST_IF, \
+        diplay_status =Utils.osso_rpc.rpc_run(MCE_SERVICE, MCE_REQUEST_PATH, MCE_REQUEST_IF, \
             MCE_DEVICE_DISPSTATUS_GET, wait_reply=True, use_system_bus=True) 
             
         if diplay_status == "off":  
@@ -866,17 +895,21 @@ class MaoboApp(QApplication):
         #print "get_unead_finished, id", accountid
 
         unread_counts = self.unread_updaters[str(accountid)].unread_counts
-        
-        #for n in unread_counts:
-        #    print n
-        #    print unread_counts[n]
+
+        if len(unread_counts) == 0:
+            return
+        for n in unread_counts:
+            print n, unread_counts[n]
+            
+        '''
 
         account_idx = 0
         for acc in self.accounts:
             if acc["id"] == accountid:
                 break
             account_idx = account_idx + 1
-
+        '''
+        
         send_all = True
         if send_all == True or self.currentAccount == None or accountid != self.currentAccount["id"] \
             or self.is_app_background_mode():    
@@ -933,12 +966,20 @@ class MaoboApp(QApplication):
             self.statusWin.comment_statuses=newStatuses
 
             self.statusWin.setWindowTitle(self.currentAccount["nickname"])
-            self.statusWin.load_status(self.settings["down_orgpic"])
+            self.statusWin.load_status(Utils.settings["down_orgpic"], self.currentAccount)
         else:
-            self.statusWin.load_status(self.settings["down_orgpic"])
+            self.statusWin.load_status(Utils.settings["down_orgpic"], self.currentAccount)
                        
         self.statusWin.currentOpe=None
         
+    def update_user_finished(self, uid, screen_name):
+        self.logger.debug("update_user_finished")
+        #self.set_windows_status(0)
+        user=self.updater.user
+        self.userWin.load_user(user)
+        self.userWin.load_friendship(self.updater.get_friendship(user))
+        self.controller.save_a_user(user)
+        
     def update_finished(self,completed):
         #print "update_finished"
         self.logger.debug("update_finished")
@@ -956,7 +997,7 @@ class MaoboApp(QApplication):
                     newStatuses.remove(newStatus)
                     
         if self.unread_updaters[str(self.currentAccount["id"])].isRunning() != True:
-            print "update_finished: update unread counts"
+            #print "update_finished: update unread counts"
             self.unread_updaters[str(self.currentAccount["id"])].initialize(self.currentAccount["id"],Utils.TIMELINE_TYPE_UNREAD)        
             self.unread_updaters[str(self.currentAccount["id"])].start()
 
@@ -974,7 +1015,7 @@ class MaoboApp(QApplication):
             if self.currentOpe==self.updateOpe:
                 self.statuses.remove(self.updateOpe)
                 
-                if len(newStatuses)==int(self.settings["updatenum"]) and len(self.statuses)>1:
+                if len(newStatuses)==int(Utils.settings["updatenum"]) and len(self.statuses)>1:
                     self.logger.debug("add a gap status")
                     
                     gapStatus=Utils.build_a_gap_status(self.currentAccount["id"])
@@ -1009,7 +1050,7 @@ class MaoboApp(QApplication):
                 row=self.gapRow
                 gapStatus=self.statuses[row]
                 self.controller.del_status_by_id(self.currentAccount["id"],gapStatus["id"])
-                if len(newStatuses)==int(self.settings["updatenum"]):
+                if len(newStatuses)==int(Utils.settings["updatenum"]):
                     self.logger.debug("add a gap status")
                     
                     newgapStatus=Utils.build_a_gap_status(self.currentAccount["id"])
@@ -1080,12 +1121,12 @@ class MaoboApp(QApplication):
                 oldestStatus=self.statuses[-2]
                 maxId=oldestStatus["id"]
                 self.logger.debug("maxId:"+str(maxId))
-                self.updater.initialize(self.currentAccount["id"],self.timelineType,None,maxId,self.settings["updatenum"],self.settings["downpic"])
+                self.updater.initialize(self.currentAccount["id"],self.timelineType,None,maxId,Utils.settings["updatenum"],Utils.settings["downpic"])
             else:
                 oldestStatus=self.statuses[-2]
                 pagetime=oldestStatus["bmiddle_pic"]
     	        pageflag=1
-                self.updater.initialize(self.currentAccount["id"],self.timelineType,pageflag,pagetime,self.settings["updatenum"],self.settings["downpic"])
+                self.updater.initialize(self.currentAccount["id"],self.timelineType,pageflag,pagetime,Utils.settings["updatenum"],Utils.settings["downpic"])
             
             
 #            try:
@@ -1121,24 +1162,51 @@ class MaoboApp(QApplication):
         self.statusWin.comment_statuses=[]
             
         self.statusWin.show()
-        self.statusWin.load_status(self.settings["down_orgpic"])
+        self.statusWin.load_status(Utils.settings["down_orgpic"], self.currentAccount)
         self.statusWin.setWindowTitle(self.currentAccount["nickname"])
         #self.statusWin.switch(self.orientation)
         self.statusWin.show()
         self.statusWin.repaint()
 
     def create_new_status_window(self,parent):
-        self.newStatusWin=NewStatusWindow(parent, Utils.g_orietation)
+        self.newStatusWin=NewStatusWindow(parent, Utils.g_orientation)
         self.connect(self.newStatusWin.sendBtn,
                      SIGNAL("clicked()"),
                      self.send_a_status)
+                     
+    def show_user(self, user=None):
+        user = self.statusWin.userBtn.user
+        
+        self.userWin = UserWindow(self.statusWin, user, self.currentAccount)#, self.updater.get_userid())
+        #self.userWin.setWindowTitle(user['name'])
+        self.userWin.switch(Utils.g_orientation)
+        self.userWin.show()
+        self.userWin.setAttribute(Qt.WA_Maemo5ShowProgressIndicator, Qt.Checked)
 
+        self.userWin.update_user_info(self.currentAccount,user["id"], user['screen_name'])
+            
+    def show_user_window(self, user=None):
+        user = self.controller.get_a_user_by_id(self.currentAccount["id"],\
+            self.updater.get_userid())
+        
+        self.userWin = UserWindow(self.statusWin, user, self.currentAccount, \
+            self.timelineWin.menuModel.get_unread_counts(4))#, self.updater.get_userid())
+        #self.userWin.setWindowTitle(user['name'])
+        self.userWin.switch(Utils.g_orientation)
+        self.userWin.show()
+        self.userWin.setAttribute(Qt.WA_Maemo5ShowProgressIndicator, Qt.Checked)
 
+        if user != None:
+            self.userWin.update_user_info(self.currentAccount, \
+                self.updater.get_userid(), user['screen_name'])
+        else:
+            self.userWin.update_user_info(self.currentAccount, self.updater.get_userid())        
+        
     def show_new_status_window(self,status=None):
         self.create_new_status_window(self.timelineWin)
         self.newStatusWin.setWindowTitle(self.currentAccount["nickname"])
         self.newStatusWin.load_status(None, None)
-        self.newStatusWin.switch(Utils.g_orietation)
+        self.newStatusWin.switch(Utils.g_orientation)
         self.newStatusWin.show()
 
     def rt_a_status(self):
@@ -1165,12 +1233,11 @@ class MaoboApp(QApplication):
                 self.newStatusWin.load_status(self.statusWin.reply_status,Utils.TIMELINE_TYPE_COMMENTS, 1)
                 self.newStatusWin.show()
 
-        
+    '''    
     def dm_a_status(self):
         self.create_new_status_window(self.statusWin)
         self.newStatusWin.load_status(self.currentStatus,Utils.TIMELINE_TYPE_DM)
         self.newStatusWin.show()
-
     def fav_a_status(self):
         #just fav it locally!!!
         favorited=self.currentStatus["favorited"]
@@ -1180,6 +1247,7 @@ class MaoboApp(QApplication):
         self.controller.favour_a_status(self.currentAccount["id"],self.currentStatus,fav)
         self.currentStatus["favorited"]=fav
         self.statusWin.change_favBtn_text(fav)
+    '''
 
     def send_a_status(self):
         self.logger.debug("send_a_status")
@@ -1190,19 +1258,6 @@ class MaoboApp(QApplication):
             return
         self.newStatusWin.enable_send(False)
         
-        #parse sina comments.
-        #if self.currentStatus["if_comments"]==1:
-        #    if self.currentStatus["bmiddle_pic"]==None:
-        #        param["cid"]=int(param["id"])
-        #        param["id"]=int(currentStatus["if_dm"])
-        #    else:
-        #        if len(self.currentStatus["bmiddle_pic"])!=10:
-        #            param["cid"]=int(param["id"])
-        #            param["id"]=int(currentStatus["if_dm"])
-        
-        #print "debug!"
-        #print param
-        
         self.sender.initialize(self.currentAccount["id"],param)
         
         self.show_notice("微博发送中...")
@@ -1215,7 +1270,7 @@ class MaoboApp(QApplication):
         self.newStatusWin.enable_send(True)
         if completed:
 #            self.show_notice("微博已成功发送",0)
-            self.newStatusWin.hide()
+            self.newStatusWin.close()
 
 
     def create_accounts_mana_form(self,accounts):
@@ -1314,7 +1369,7 @@ class MaoboApp(QApplication):
         self.accountsWin.accountsListView.setModel(self.accountsModel)
 
     def show_setting_form(self):
-        self.settingForm=SettingForm(self.accountsWin, self.settings)
+        self.settingForm=SettingForm(self.accountsWin, Utils.settings)
         self.connect(self.settingForm.confirmButton,
                      SIGNAL("clicked()"),
                      self.save_settings)
@@ -1325,10 +1380,11 @@ class MaoboApp(QApplication):
         if settings!=None:
             settings = self.controller.save_settings(settings)
             if settings!=None:
-                self.settings=settings
+#                self.settings=settings
+                Utils.settings = settings 
                 #self.show_notice("成功保存微博设置")
         if self.accountsWin != None:
-            self.accountsWin.set_running_mode(self.settings["background"])
+            self.accountsWin.set_running_mode(Utils.settings["background"])
 
         self.settingForm.hide()
 
@@ -1390,8 +1446,7 @@ class MaeboService(dbus.service.Object):
     @dbus.service.method(dbus_interface=SESSION_DBUS_IFACE)
     def show_window(self):
         self.app.accountsWin.activateWindow()   
-        self.app.accountsWin.show()  
-        print "show_window"
+        self.app.accountsWin.show()             
 
 def main():    
     if dbus.SessionBus().request_name(SESSION_DBUS_NAME) != dbus.bus.REQUEST_NAME_REPLY_PRIMARY_OWNER:
@@ -1411,7 +1466,7 @@ def main():
 	    if os.access(dir, os.W_OK) == 0:
 	        os.mkdir(dir)
 	    # set up logging to file - see previous section for more details
-	    logging.basicConfig(level=logging.INFO,
+	    logging.basicConfig(level=logging.DEBUG,
 	                        format='%(asctime)s %(name)-12s %(levelname)-8s %(message)s',
 	                        datefmt='%y-%m-%d %H:%M',
 	                        filename=Utils.LOG_FILE,
@@ -1445,6 +1500,5 @@ def main():
 #    notification.close()
 #    print "on_state_reason_notification_closed"
 
-
 main()
 
